Quicklook of an X-ray observation
*********************************

Stingray transparently loads datasets from many HEASOFT-supported missions.
In this Tutorial, we will show an example quicklook of a NuSTAR observation.

.. toctree::
   :maxdepth: 2

   notebooks/DataQuickLook/Quicklook NuSTAR data with Stingray.ipynb
